pub fn hook_available(
repo: &Repository,
other_paths: Option<&[&str]>,
hook: &str,
) -> Result<bool, HooksError>Expand description
Check if a given hook is present considering config/paths and optional extra paths.
pub fn hook_available(
repo: &Repository,
other_paths: Option<&[&str]>,
hook: &str,
) -> Result<bool, HooksError>Check if a given hook is present considering config/paths and optional extra paths.